@@ -39,7 +39,7 @@ class daystyle(graph.style._style):
 year = 2012
 notes = {1: {17: r"\PyX{} 0.2 (2003)", 20: r"\PyX{} 0.5 (2004)", 22: r"\PyX{} 0.5.1 (2004)"},
          3: {30: r"\PyX{} 0.6 (2004)", 31: r"\PyX{} 0.3 ('03), \PyX{} 0.6.1 ('04)"},
-         4: {4: r"\PyX{} 0.3.1 (2003)", 7: r"\PyX{} 0.6.2 (2004)", 27: r"\PyX{} 0.6.3 (2004)"},
+         4: {4: r"\PyX{} 0.3.1 (2003)", 7: r"\PyX{} 0.6.2 (2004)", 27: r"\PyX{} 0.6.3 (2004)", 30: r"\PyX{} 0.14 (2015)"},
          5: {5: r"\PyX{} 0.11 (2011)", 20: r"\PyX{} 0.11.1 (2011)", 24: r"\PyX{} 0.9 (2006)"},
          7: {13: r"\PyX{} 0.8 (2005)"},
          8: {13: r"\PyX{} 0.8.1 (2005)", 22: r"\PyX{} 0.4 (2003)"},
@@ -75,3 +75,4 @@ c.text(gcbb.right()+0.5, gcbb.center()[1], r"\dots")
 c.text(gcbb.center()[0], gcbb.bottom()-0.5, r"\dots")
 c.writeEPSfile("cal")
 c.writePDFfile("cal")
+c.writeSVGfile("cal")
